@@ -17,13 +17,15 @@ from enum import IntEnum
 
 from gi.repository import Gtk
 
+from nbxmpp.modules import dataforms
+
 from gajim.common import app
-from gajim.common.modules import dataforms
 from gajim.common.i18n import _
 
-from gajim.gtk.dataform import DataFormWidget
+from .dataform import DataFormWidget
+from .dataform import FakeDataFormWidget
 
-log = logging.getLogger('gajim.gtk.registration')
+log = logging.getLogger('gajim.gui.registration')
 
 
 class Page(IntEnum):
@@ -77,13 +79,16 @@ class ServiceRegistration(Gtk.Assistant):
 
     def _build_dataform(self, form, is_form):
         if not is_form:
-            from gajim import config
-            return config.FakeDataForm(form)
+            return FakeDataFormWidget(form)
 
         dataform = dataforms.extend_form(node=form)
-        return DataFormWidget(dataform)
 
-    def _on_page_change(self, assistant, page):
+        form_widget = DataFormWidget(dataform)
+        form_widget.connect('is-valid', self._on_is_valid)
+        form_widget.validate()
+        return form_widget
+
+    def _on_page_change(self, _assistant, _page):
         if self.get_current_page() == Page.REQUEST:
             self._con.get_module('Register').get_register_form(
                 self._agent, self._on_get_success, self._on_error)
@@ -95,36 +100,31 @@ class ServiceRegistration(Gtk.Assistant):
         log.info('Show Form page')
         self._is_form = is_form
         self._data_form_widget = self._build_dataform(form, is_form)
-
         self.get_nth_page(Page.FORM).set_form(self._data_form_widget)
         self.set_current_page(Page.FORM)
 
+    def _on_is_valid(self, _widget, is_valid):
+        self.set_page_complete(self.get_nth_page(Page.FORM), is_valid)
+
     def _on_error(self, error_text, form=None, is_form=False):
         if form is not None:
             log.info('Show Form page')
             self._is_form = is_form
             self._data_form_widget = self._build_dataform(form, is_form)
-            self.get_nth_page(Page.FORM).set_form(self._data_form_widget, error_text=error_text)
+            self.get_nth_page(Page.FORM).set_form(self._data_form_widget,
+                                                  error_text=error_text)
             self.set_current_page(Page.FORM)
         else:
             log.info('Show Error page')
             self.get_nth_page(Page.ERROR).set_text(error_text)
             self.set_current_page(Page.ERROR)
 
-    def _on_cancel(self, widget):
+    def _on_cancel(self, _widget):
         self.destroy()
 
     def _register(self):
         log.info('Show Sending page')
-        if self._is_form:
-            form = self._data_form_widget.get_submit_form()
-        else:
-            form = self._data_form_widget.get_infos()
-            if 'instructions' in form:
-                del form['instructions']
-            if 'registered' in form:
-                del form['registered']
-
+        form = self._data_form_widget.get_submit_form()
         self._con.get_module('Register').register_agent(
             self._agent,
             form,
